/// <reference types="react" />
import "./style.css";
export declare type ExpressionID = number | string;
/**
 * A LoF expression tree.
 * Contains all required data to draw and calculate LoF expressions
 */
export declare type LoFExpressionTree<T> = {
    data: T;
    id: ExpressionID;
    expressions: (LoFExpressionTree<T> | ExpressionID)[];
    depth: number;
    maxDepth: number;
};
/**
 * @param {LoFExpressionTree} expression - Expression tree of (nested) Laws of Form expressions
 *
 * Creates JSX of nested Laws of Form expressions. Size is based on the parents font-size.
 * Since the reentry drawing happens purely with pseudo divs (::before, ::after),
 * we can only reenter a specific subexpression twice into the form.
 */
export default function LoF<T>({ expressionTree, className, style, children, unwrittenCross, uc, }: {
    expressionTree?: LoFExpressionTree<T>;
    className?: string;
    style?: React.CSSProperties;
    children?: React.ReactNode;
    unwrittenCross?: boolean;
    uc?: boolean;
}): JSX.Element;
